@@ -22,7 +22,7 @@ class ColumnMetadata(BaseModel):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         if 'name' not in kwargs or 'type' not in kwargs:
-            raise MetadataError('prout2')
+            raise MetadataError('name is required')
         self.name: str = kwargs['name'].upper()
         self.original_name: str = kwargs['name']
         self.type: str = kwargs['type'].upper()
@@ -71,7 +71,7 @@ class TableMetadata(BaseModel):
     def __init__(self, **kwargs):
         super().__init__(**kwargs)
         if 'name' not in kwargs:
-            raise MetadataError('prout')
+            raise MetadataError('Name is required')
         self.name: str = kwargs['name'].upper()
         self.original_name: str = kwargs['name']
 
