@@ -1,4 +1,4 @@
-from typing import List, Optional, Tuple, Union
+from typing import List, Literal, Optional, Tuple, Union
 
 from pydantic import Field, root_validator
 
@@ -8,7 +8,7 @@ from weaverbird.pipeline.types import ColumnName, TemplatedVariable
 
 
 class CumSumStep(BaseStep):
-    name = Field('cumsum', const=True)
+    name: Literal['cumsum'] = 'cumsum'
     to_cumsum: List[Tuple[str, Optional[str]]] = Field(..., alias='toCumSum')
     reference_column: ColumnName = Field(..., alias='referenceColumn')
     groupby: Optional[List[ColumnName]]
