@@ -1,12 +1,10 @@
-from typing import Optional
-
-from pydantic import Field
+from typing import Literal, Optional
 
 from weaverbird.pipeline.steps.utils.base import BaseStep
 from weaverbird.pipeline.types import ColumnName
 
 
 class ToDateStep(BaseStep):
-    name = Field('todate', const=True)
+    name: Literal['todate'] = 'todate'
     column: ColumnName
     format: Optional[str]
